@@ -6,9 +6,7 @@
 _m = __import__
 
 logging = _m('logging').getLogger('ops')
-
-DIRECTORY_STACK_NAME = '__ops_directory_stack'
-_TYPE = type
+type_ = type
 
 def _chmod(path, value=None):
     if isinstance(value, int):
@@ -159,11 +157,11 @@ def env_set(name, value, add=False, append=False, prepend=False, sep=':', unique
       True
       >>> env_set('PATH', '/sbin', append=True)
       True
-      >>> env_set('PATH')
+      >>> env_get('PATH')
       '/bin:/sbin'
       >>> env_set('PATH', '/sbin', prepend=True, sep=':', unique=True)
       False
-      >>> env_set('PATH')
+      >>> env_get('PATH')
       '/bin:/sbin'
     """
     if add and env_has(name):
@@ -546,7 +544,7 @@ def normalize(value, default=None, type=None, raise_exception=False):
     if type is None and default is None:
         type = basestring
     elif type is None:
-        type = _TYPE(default)
+        type = type_(default)
     if type in (basestring, 'basestring'):
         if value is not None:
             return value
